==> hex_core-0.6.7.tar.gz: hex_api_release.md <==


# Module hex_api_release #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-retirement_params">retirement_params()</a> ###


<pre><code>
retirement_params() = #{reason =&gt; <a href="#type-retirement_reason">retirement_reason()</a>, message =&gt; binary()}
</code></pre>




### <a name="type-retirement_reason">retirement_reason()</a> ###


<pre><code>
retirement_reason() = other | invalid | security | deprecated | renamed
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#delete-3">delete/3</a></td><td>
Deletes a package release.</td></tr><tr><td valign="top"><a href="#get-3">get/3</a></td><td>
Gets a package release.</td></tr><tr><td valign="top"><a href="#publish-2">publish/2</a></td><td>
Publishes a new package release.</td></tr><tr><td valign="top"><a href="#retire-4">retire/4</a></td><td>
Retires a package release.</td></tr><tr><td valign="top"><a href="#unretire-3">unretire/3</a></td><td>
Unretires a package release.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="delete-3"></a>

### delete/3 ###

<pre><code>
delete(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Deletes a package release.

Examples:

```
  > hex_api_release:delete(hex_core:default_config(), <<"package">>, <<"1.0.0">>).
  {ok, {204, ..., nil}}
```

<a name="get-3"></a>

### get/3 ###

<pre><code>
get(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Gets a package release.

Examples:

```
  > hex_api_release:get(hex_core:default_config(), <<"package">>, <<"1.0.0">>).
  {ok, {200, ..., #{
       <<"checksum">> => <<"540d210d81f56f17f64309a4896430e727972499b37bd59342dc08d61dff74d8">>,
       <<"docs_html_url">> => <<"https://hexdocs.pm/package/1.0.0/">>,
       <<"downloads">> => 740,<<"has_docs">> => true,
       <<"html_url">> => <<"https://hex.pm/packages/package/1.0.0">>,
       <<"inserted_at">> => <<"2014-12-09T18:32:03Z">>,
       <<"meta">> =>
           #{<<"app">> => <<"package">>,
             <<"build_tools">> => [<<"mix">>]},
       <<"package_url">> => <<"https://hex.pm/api/packages/package">>,
       <<"publisher">> => nil,<<"requirements">> => #{},
       <<"retirement">> => nil,
       <<"updated_at">> => <<"2019-07-28T21:12:11Z">>,
       <<"url">> => <<"https://hex.pm/api/packages/package/releases/1.0.0">>,
       <<"version">> => <<"1.0.0">>
       }}}
```

<a name="publish-2"></a>

### publish/2 ###

<pre><code>
publish(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Tarball::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Publishes a new package release.

Examples:

```
  > hex_api_release:publish(hex_core:default_config(), Tarball).
  {ok, {200, ..., #{
       <<"checksum">> => <<"540d210d81f56f17f64309a4896430e727972499b37bd59342dc08d61dff74d8">>,
       <<"docs_html_url">> => <<"https://hexdocs.pm/package/1.0.0/">>,
       <<"downloads">> => 740,<<"has_docs">> => true,
       <<"html_url">> => <<"https://hex.pm/packages/package/1.0.0">>,
       <<"inserted_at">> => <<"2014-12-09T18:32:03Z">>,
       <<"meta">> =>
           #{<<"app">> => <<"package">>,
             <<"build_tools">> => [<<"mix">>]},
       <<"package_url">> => <<"https://hex.pm/api/packages/package">>,
       <<"publisher">> => nil,<<"requirements">> => #{},
       <<"retirement">> => nil,
       <<"updated_at">> => <<"2019-07-28T21:12:11Z">>,
       <<"url">> => <<"https://hex.pm/api/packages/package/releases/1.0.0">>,
       <<"version">> => <<"1.0.0">>
       }}}
```

<a name="retire-4"></a>

### retire/4 ###

<pre><code>
retire(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary(), Params::<a href="#type-retirement_params">retirement_params()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Retires a package release.

Examples:

```
  > hex_api_release:retire(hex_core:default_config(), <<"package">>, <<"1.0.0">>, Params).
  {ok, {204, ..., nil}}
```

<a name="unretire-3"></a>

### unretire/3 ###

<pre><code>
unretire(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Unretires a package release.

Examples:

```
  > hex_api_release:unretire(hex_core:default_config(), <<"package">>, <<"1.0.0">>).
  {ok, {204, ..., nil}}
```

==> hex_core-0.6.9.tar.gz: hex_api_release.md <==


# Module hex_api_release #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-publish_params">publish_params()</a> ###


<pre><code>
publish_params() = [{replace, boolean()}]
</code></pre>




### <a name="type-retirement_params">retirement_params()</a> ###


<pre><code>
retirement_params() = #{reason =&gt; <a href="#type-retirement_reason">retirement_reason()</a>, message =&gt; binary()}
</code></pre>




### <a name="type-retirement_reason">retirement_reason()</a> ###


<pre><code>
retirement_reason() = other | invalid | security | deprecated | renamed
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#delete-3">delete/3</a></td><td>
Deletes a package release.</td></tr><tr><td valign="top"><a href="#get-3">get/3</a></td><td>
Gets a package release.</td></tr><tr><td valign="top"><a href="#publish-2">publish/2</a></td><td>
Publishes a new package release.</td></tr><tr><td valign="top"><a href="#publish-3">publish/3</a></td><td>
Publishes a new package release with query parameters.</td></tr><tr><td valign="top"><a href="#retire-4">retire/4</a></td><td>
Retires a package release.</td></tr><tr><td valign="top"><a href="#unretire-3">unretire/3</a></td><td>
Unretires a package release.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="delete-3"></a>

### delete/3 ###

<pre><code>
delete(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Deletes a package release.

Examples:

```
  > hex_api_release:delete(hex_core:default_config(), <<"package">>, <<"1.0.0">>).
  {ok, {204, ..., nil}}
```

<a name="get-3"></a>

### get/3 ###

<pre><code>
get(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Gets a package release.

Examples:

```
  > hex_api_release:get(hex_core:default_config(), <<"package">>, <<"1.0.0">>).
  {ok, {200, ..., #{
       <<"checksum">> => <<"540d210d81f56f17f64309a4896430e727972499b37bd59342dc08d61dff74d8">>,
       <<"docs_html_url">> => <<"https://hexdocs.pm/package/1.0.0/">>,
       <<"downloads">> => 740,<<"has_docs">> => true,
       <<"html_url">> => <<"https://hex.pm/packages/package/1.0.0">>,
       <<"inserted_at">> => <<"2014-12-09T18:32:03Z">>,
       <<"meta">> =>
           #{<<"app">> => <<"package">>,
             <<"build_tools">> => [<<"mix">>]},
       <<"package_url">> => <<"https://hex.pm/api/packages/package">>,
       <<"publisher">> => nil,<<"requirements">> => #{},
       <<"retirement">> => nil,
       <<"updated_at">> => <<"2019-07-28T21:12:11Z">>,
       <<"url">> => <<"https://hex.pm/api/packages/package/releases/1.0.0">>,
       <<"version">> => <<"1.0.0">>
       }}}
```

<a name="publish-2"></a>

### publish/2 ###

<pre><code>
publish(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Tarball::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Publishes a new package release.

Examples:

```
  > hex_api_release:publish(hex_core:default_config(), Tarball).
  {ok, {200, ..., #{
       <<"checksum">> => <<"540d210d81f56f17f64309a4896430e727972499b37bd59342dc08d61dff74d8">>,
       <<"docs_html_url">> => <<"https://hexdocs.pm/package/1.0.0/">>,
       <<"downloads">> => 740,<<"has_docs">> => true,
       <<"html_url">> => <<"https://hex.pm/packages/package/1.0.0">>,
       <<"inserted_at">> => <<"2014-12-09T18:32:03Z">>,
       <<"meta">> =>
           #{<<"app">> => <<"package">>,
             <<"build_tools">> => [<<"mix">>]},
       <<"package_url">> => <<"https://hex.pm/api/packages/package">>,
       <<"publisher">> => nil,<<"requirements">> => #{},
       <<"retirement">> => nil,
       <<"updated_at">> => <<"2019-07-28T21:12:11Z">>,
       <<"url">> => <<"https://hex.pm/api/packages/package/releases/1.0.0">>,
       <<"version">> => <<"1.0.0">>
       }}}
```

<a name="publish-3"></a>

### publish/3 ###

<pre><code>
publish(Config::<a href="hexcore.md#type-config">hexcore:config()</a>, Tarball::binary(), Params::<a href="#type-publish_params">publish_params()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Publishes a new package release with query parameters.

Supported query params :
- replace : boolean

Examples:

```
  > hex_api_release:publish(hex_core:default_config(), Tarball, [{replace, true}]).
  {ok, {201, ..., #{
       <<"checksum">> => <<"540d210d81f56f17f64309a4896430e727972499b37bd59342dc08d61dff74d8">>,
       <<"docs_html_url">> => <<"https://hexdocs.pm/package/1.0.0/">>,
       <<"downloads">> => 740,<<"has_docs">> => true,
       <<"html_url">> => <<"https://hex.pm/packages/package/1.0.0">>,
       <<"inserted_at">> => <<"2014-12-09T18:32:03Z">>,
       <<"meta">> =>
           #{<<"app">> => <<"package">>,
             <<"build_tools">> => [<<"mix">>]},
       <<"package_url">> => <<"https://hex.pm/api/packages/package">>,
       <<"publisher">> => nil,<<"requirements">> => #{},
       <<"retirement">> => nil,
       <<"updated_at">> => <<"2019-07-28T21:12:11Z">>,
       <<"url">> => <<"https://hex.pm/api/packages/package/releases/1.0.0">>,
       <<"version">> => <<"1.0.0">>
       }}}
```

<a name="retire-4"></a>

### retire/4 ###

<pre><code>
retire(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary(), Params::<a href="#type-retirement_params">retirement_params()</a>) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Retires a package release.

Examples:

```
  > hex_api_release:retire(hex_core:default_config(), <<"package">>, <<"1.0.0">>, Params).
  {ok, {204, ..., nil}}
```

<a name="unretire-3"></a>

### unretire/3 ###

<pre><code>
unretire(Config::<a href="hex_core.md#type-config">hex_core:config()</a>, Name::binary(), Version::binary()) -&gt; <a href="hex_api.md#type-response">hex_api:response()</a>
</code></pre>
<br />

Unretires a package release.

Examples:

```
  > hex_api_release:unretire(hex_core:default_config(), <<"package">>, <<"1.0.0">>).
  {ok, {204, ..., nil}}
```
